@@ -28,6 +28,10 @@ EnvironmentYml = Dict[str, Union[List[str], str]]
 
 
 class Conda(Environment):
+    """
+    Conda EnvManager class.
+    """
+
     def __init__(
         self,
         name: str,
@@ -73,6 +77,10 @@ class Conda(Environment):
         envs_dir = self.get_envs_dir()
         return envs_dir.joinpath(f"{self.name}/bin/python")
 
+    @property
+    def info_name(self) -> str:
+        return "conda"
+
     def raise_for_conda(self) -> None:
         """
         Helper method which either raises if no `conda` found.
@@ -143,10 +151,7 @@ class Conda(Environment):
         if packages:
             cmd.extend(packages)
 
-        try:
-            _ = subprocess.run(cmd, check=True, capture_output=True)
-        except subprocess.CalledProcessError:
-            raise
+        subprocess.run(cmd, check=True, capture_output=True)
 
     @staticmethod
     def create_from_yml(project_path: Path) -> Conda:
@@ -204,7 +209,6 @@ class Conda(Environment):
                     "conda",
                     "env",
                     "create",
-                    "-y",
                     "--file",
                     f"{yml_file}",
                 ],
@@ -300,6 +304,13 @@ class Conda(Environment):
         except subprocess.CalledProcessError:
             raise
 
+    def install_self(self) -> None:
+        """
+        Creates a conda environment from an environment.yml,
+        this is conda's closest concept to `installing self`.
+        """
+        self.create_from_yml(project_path=self.project_path)
+
     @staticmethod
     def get_envs_dir() -> Path:
         """
